Based on our meta-analysis, returns a response value for a specific cause or disease.
1. Disease/Cause: Name of the disease/cause - from a specific list
2. Type: Fatal, non-fatal or fatal-and-non-fatal.

dose_response(
  cause,
  outcome_type,
  dose,
  quantile = 0.5,
  censor_method = "default",
  confidence_intervals = F
)

Arguments

cause

All-cause-mortality or disease name

outcome_type

Fatal, non-fatal or fatal-and-non-fatal

dose

Dose (all-cause or disease)

quantile

Numeric value between 0 and 1 - default is 0.5

censor_method

Censoring method to use. Options are:

`none`

No censoring.

`default`

The default censoring method identified by the meta-analysis.

`WHO-DRL`

A fixed WHO-recommended double level of physical activity (17.5 MMET-hours per week).

`WHO-QRL`

A fixed WHO-recommended quadruple level of physical activity (35 MMET-hours per week).

confidence_intervals

Boolean variable to determine whether confidence intervals are returned or not - default is FALSE

Value

response for a specific dose (in a data frame)

Details

At the end, this function returns a response values with or without confidence interval