dose_response.RdBased on our meta-analysis, returns a response value for a specific cause or disease.
1. Disease/Cause: Name of the disease/cause - from a specific list
2. Type: Fatal, non-fatal or fatal-and-non-fatal.
dose_response(
cause,
outcome_type,
dose,
quantile = 0.5,
censor_method = "default",
confidence_intervals = F
)All-cause-mortality or disease name
Fatal, non-fatal or fatal-and-non-fatal
Dose (all-cause or disease)
Numeric value between 0 and 1 - default is 0.5
Censoring method to use. Options are:
No censoring.
The default censoring method identified by the meta-analysis.
A fixed WHO-recommended double level of physical activity (17.5 MMET-hours per week).
A fixed WHO-recommended quadruple level of physical activity (35 MMET-hours per week).
Boolean variable to determine whether confidence intervals are returned or not - default is FALSE
response for a specific dose (in a data frame)
At the end, this function returns a response values with or without confidence interval